<?php

namespace Teknisa\EST\Modules\Ajuste\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Filter;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\EST\Modules\Ajuste\Services\Est43000ManutencaoDoUltimoCustoService;
    
class Est43000ManutencaoDoUltimoCustoController extends \Teknisa\EST\Controllers\TeknisaCrud {
    protected $dataSourceName = '';
	protected $parameterBagColumns = array('');
    protected $service;

    public function __construct($crudService, $parameterBag, $service, $entityManager) {
        parent::__construct($crudService, $parameterBag);
        $this->service = $service;
        $this->entityManager = $entityManager;
    }   
    
    
    public function findProduto(DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $request->getFilterCriteria()->getConditions();
        
        $CDNVPRODUTO = array_filter($conditions, function($condition){
            if($condition['columnName'] == "CDNVPRODUTO")
                return $condition["value"];
        });
        
        $products = $this->service->getProducts($CDNVPRODUTO[0]["value"]);
        $response->addDataSet(new DataSet("get_produto", $products));
    }
    
    public function saveManutencao(DTO\Request $request, DTO\Response $response) {
        $this->service->saveManutencao($request,$response);
    }
    
    public function atualizaUltimoCusto(DTO\Request $request, DTO\Response $response) {
        try{
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            $row = $request->getRow();
            $result = $this->service->atualizaUltimoCusto($row);
            $dataSet = new DataSet('custocmprod_produto_prodfili', $result);
            $response->addDataSet($dataSet);
        }
        catch(\Exception $e){
            $this->entityManager->rollback();
			$response->setError(new Error($e->getMessage(), 500));
		}
    }
    
    public function importaUltimoCusto(DTO\Request $request, DTO\Response $response) {
        try{
            $connection = $this->entityManager->getConnection();
            $connection->beginTransaction();
            $row = $request->getRow();
            if(!isset($row['CDALMOXARIFE'])) $row['CDALMOXARIFE'] = NULL;
            if(!isset($row['CDLOCALESTOQ'])) $row['CDLOCALESTOQ'] = NULL;
            $rowProdutos = $this->service->buscaProdutosParaImportacao($row['CDFILIAL'], $row['DTREFERENCIA'], $row['CDLOCALESTOQ'], $row['CDALMOXARIFE'], $row['CDPRODINI'], $row['CDPRODFIN']);
            $rowInsert = $this->service->preparaRowsImportacao($rowProdutos, $row);
            $this->service->insereProdutosImportados($rowInsert);
            $connection->commit();
        }
        catch(\Exception $e){
            $this->entityManager->rollback();
			$response->setError(new Error($e->getMessage(), 500));
		}
    }
}
